@@ -14,19 +14,21 @@
 #include "resources/eventmodel.h"
 #include "lib/messagebox.h"
 #include "kalarmcalendar/kaevent.h"
+#include "config-kalarm.h"
 
 #include <KFindDialog>
 #include <KFind>
 #include <KSeparator>
-#include <KWindowSystem>
 #include <KLocalizedString>
+#if ENABLE_X11
+#include <KX11Extras>
+#endif
 
 #include <QGroupBox>
 #include <QCheckBox>
 #include <QVBoxLayout>
 #include <QGridLayout>
 #include <QRegularExpression>
-#include <kwidgetsaddons_version.h>
 
 using namespace KAlarmCal;
 
@@ -81,7 +83,11 @@ void Find::display()
         mOptions &= ~FIND_ARCHIVED;
 
     if (mDialog)
-        KWindowSystem::activateWindow(mDialog->winId());
+    {
+#if ENABLE_X11
+        KX11Extras::activateWindow(mDialog->winId());
+#endif
+    }
     else
     {
         mDialog = new KFindDialog(mListView, mOptions, mHistory, (mListView->selectionModel()->selectedRows().count() > 1));
@@ -378,11 +384,7 @@ void Find::findNext(bool forward, bool checkEnd, bool fromCurrent)
         {
             const QString msg = forward ? xi18nc("@info", "<para>End of alarm list reached.</para><para>Continue from the beginning?</para>")
                                         : xi18nc("@info", "<para>Beginning of alarm list reached.</para><para>Continue from the end?</para>");
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
             if (KAMessageBox::questionYesNo(mListView, msg, QString(), KStandardGuiItem::cont(), KStandardGuiItem::cancel()) == KMessageBox::ButtonCode::PrimaryAction)
-#else
-            if (KAMessageBox::questionYesNo(mListView, msg, QString(), KStandardGuiItem::cont(), KStandardGuiItem::cancel()) == KMessageBox::Yes)
-#endif
             {
                 mNoCurrentItem = true;
                 findNext(forward, false, false);
